repo
stringclasses
15 values
fix_commit
stringlengths
40
40
buggy_commit
stringlengths
40
40
message
stringlengths
3
64.3k
files
listlengths
1
300
timestamp
timestamp[s]date
2013-03-13 20:45:00
2026-04-11 07:48:46
ggml-org/llama.cpp
0685848bc64793f6181d82ff4b92b358066cb4af
0024a69b701968bc9ba415b81ef6a11f02d94adf
scripts : remove get-wikitext-103.sh (#20543) It doesn't work and no one seems to use it. $ wget https://s3.amazonaws.com/research.metamind.io/wikitext/wikitext-103-raw-v1.zip HTTP request sent, awaiting response... 301 Moved Permanently Location: unspecified ERROR: Redirection (301) without location....
[ { "path": "scripts/get-wikitext-103.sh", "patch": "@@ -1,10 +0,0 @@\n-#!/usr/bin/env bash\n-\n-wget https://s3.amazonaws.com/research.metamind.io/wikitext/wikitext-103-raw-v1.zip\n-\n-echo \"Usage:\"\n-echo \"\"\n-echo \" ./llama-perplexity -m model.gguf -f wiki.test.raw [other params]\"\n-echo \"\"\n-\n-e...
2026-03-14T10:22:04
ollama/ollama
070ad913acf2b62df55ba6c638f5d287ffd6fa8f
8d8b9f83ae998fef76ceb1350175af74cb1a697a
ci: fix linux archive
[ { "path": ".github/workflows/release.yaml", "patch": "@@ -305,30 +305,27 @@ jobs:\n - uses: docker/setup-buildx-action@v3\n - run: |\n sudo apt-get update && sudo apt-get install pigz\n- docker buildx build --platform $PLATFORM --target ${{ matrix.target }} --build-arg GOFLAGS...
2025-02-05T22:02:48
vuejs/vue
0d6d972b32521fd18eb853b1073c0a19859a499a
bc5b92adde147436f2adb25e457f0c967829467f
fix(compiler-sfc): export parseComponent for compat with fork-ts-checker-webpack-plugin fix #12719
[ { "path": "packages/compiler-sfc/src/index.ts", "patch": "@@ -6,6 +6,13 @@ export { compileScript } from './compileScript'\n export { generateCodeFrame } from 'compiler/codeframe'\n export { rewriteDefault } from './rewriteDefault'\n \n+// For backwards compat only. Some existing tools like\n+// fork-ts-che...
2022-10-11T06:58:24
golang/go
5e82cba9bdf45d81da549477d172f6b5e23106d4
45869f5931554f0db1169bc268db7ffd8d400e9e
os/user: skip tests that create users when running on dev machines Creating and deleting users is tricky to get right, and it's not something we want to do on a developer machine. This change skips the tests that create users when not running on a Go builder. This will fix #70396, although I still don't understand wh...
[ { "path": "src/os/user/user_windows_test.go", "patch": "@@ -24,6 +24,13 @@ import (\n // If the user already exists, it will be deleted and recreated.\n // The caller is responsible for closing the token.\n func windowsTestAccount(t *testing.T) (syscall.Token, *User) {\n+\tif testenv.Builder() == \"\" {\n+\...
2024-11-18T10:07:07
huggingface/transformers
063b456914661d7625b32c0b6f156ba836dae1db
d5eab539adc06e9ad556986bda887e1e5c3f1cf1
[DeepSpeed] properly handle MoE weight conversion (#43524) * properly handle MoE weight conversion * fix style * Non-expert keys bug fix * remove dead code
[ { "path": "src/transformers/integrations/deepspeed.py", "patch": "@@ -348,6 +348,7 @@ def _apply_weight_conversions_to_state_dict(model, state_dict, weight_mapping):\n # Iterate over sorted keys and pop from state_dict to free memory immediately\n conversion_mapping = {}\n key_rename_cache = {} ...
2026-02-02T09:48:22
electron/electron
88ae6c0635c435aa7637e769ad8bb96502ede016
a0153323429a6858cc257d17a68e103088a07ce7
fix: Don't create console window when creating process (#32340) * fix: Don't create console window when creating process * Update patches/node/fix_don_t_create_console_window_when_creating_process.patch Co-authored-by: Robo <hop2deep@gmail.com> * Remove extra line in description Co-authored-by: Robo <hop2d...
[ { "path": "patches/node/.patches", "patch": "@@ -26,3 +26,4 @@ chore_fix_-wimplicit-fallthrough.patch\n test_add_fixture_trim_option.patch\n fix_crash_caused_by_gethostnamew_on_windows_7.patch\n fix_suppress_clang_-wdeprecated-declarations_in_libuv.patch\n+fix_don_t_create_console_window_when_creating_proce...
2022-01-07T08:38:34
ollama/ollama
d8932c55e72f919cd92d0d019fb7fd0e01d857cd
63f0269f7f9f6256ff92ff6a11b032df01ffba5f
server: fix out of bounds exception on model download (#8746)
[ { "path": "server/download.go", "patch": "@@ -170,9 +170,9 @@ func (b *blobDownload) Prepare(ctx context.Context, requestURL *url.URL, opts *r\n \n \t\t\toffset += size\n \t\t}\n+\t} else {\n+\t\tslog.Info(fmt.Sprintf(\"downloading %s in %d %s part(s)\", b.Digest[7:19], len(b.Parts), format.HumanBytes(b.Par...
2025-02-05T02:52:47
golang/go
107e094f51319f99f7353f1aeae36229deda34c0
700c7b95ae001244e60e820dcc4f63ae4f5fc5b1
internal/sync: refactor HashTrieMap tests into per-op suites This change does a minor refactor of the HashTrieMap tests to be better organized into suites for each operation. It might be worthwhile to deduplicate some code in here, but it's also helpful to see exactly what's happening when something goes wrong. Chang...
[ { "path": "src/internal/sync/hashtriemap_test.go", "patch": "@@ -59,602 +59,611 @@ func testHashTrieMap(t *testing.T, newMap func() *isync.HashTrieMap[string, int]\n \t\t\texpectLoaded(t, s, i)(m.LoadOrStore(s, 0))\n \t\t}\n \t})\n-\tt.Run(\"CompareAndDeleteAll\", func(t *testing.T) {\n+\tt.Run(\"All\", fun...
2024-08-15T18:53:33
vuejs/vue
bc5b92adde147436f2adb25e457f0c967829467f
fb1393009660b38046b1f6dfb532b481cc53b3b7
fix(types): fix error with options watch (#12779) fix #12780
[ { "path": "types/options.d.ts", "patch": "@@ -181,7 +181,7 @@ export interface ComponentOptions<\n propsData?: object\n computed?: Accessors<Computed>\n methods?: Methods\n- watch?: Record<string, WatchOptionsWithHandler<any> | WatchHandler<any>>\n+ watch?: Record<string, WatchOptionsWithHandler<any...
2022-10-11T06:43:33
huggingface/transformers
d5eab539adc06e9ad556986bda887e1e5c3f1cf1
4da99340864e2ed8d92d15b9f93fe1534044284a
Tie zamba weights correctly (#43623) * i guess this is what was meant to happen? * it should lock in cirlce from what it seems * zamba also needs a fix * erm? * more layers to test but it fails with new error. I need to eat and try later * model tied weights even with `tie_word_embeddings=False`, not anymore
[ { "path": "src/transformers/models/zamba/modeling_zamba.py", "patch": "@@ -844,7 +844,7 @@ def __init__(self, config: ZambaConfig):\n layers.append(ZambaHybridLayer(ZambaAttentionDecoderLayer(config), linear, mamba))\n if self._tied_weights_keys is None:\n ...
2026-02-02T09:17:35
electron/electron
a0153323429a6858cc257d17a68e103088a07ce7
5af6b898d92432369ce9495e75d75b02af651531
fix: drop nativeWindowOpen deprecation warning (#32370)
[ { "path": "lib/browser/api/web-contents.ts", "patch": "@@ -1,4 +1,4 @@\n-import { app, ipcMain, session, deprecate, webFrameMain } from 'electron/main';\n+import { app, ipcMain, session, webFrameMain } from 'electron/main';\n import type { BrowserWindowConstructorOptions, LoadURLOptions } from 'electron/mai...
2022-01-06T20:01:55
ggml-org/llama.cpp
9789c4ecdc01d571331c14e5197514b53839de4b
77e20cc1076f351f6ba37b545a20b21c6207cbe5
ggml : add OpenVINO backend (#15307) * Update build doc * Add cgraph tensor output name to OV op name * Update openvino build instructions * Add initial NPU support * draft NPU support version 2: prefill + kvcache * NPU support version 2: prefill + kvcache * Change due to ggml cgraph changes, not correct yet * ...
[ { "path": ".devops/openvino.Dockerfile", "patch": "@@ -0,0 +1,138 @@\n+ARG OPENVINO_VERSION_MAJOR=2026.0\n+ARG OPENVINO_VERSION_FULL=2026.0.0.20965.c6d6a13a886\n+ARG UBUNTU_VERSION=24.04\n+\n+# Optional proxy build arguments - empty by default\n+ARG http_proxy=\n+ARG https_proxy=\n+\n+## Build Image\n+FROM ...
2026-03-14T05:56:55
ollama/ollama
4759ecae19fb8246826a8b87da9afbe1601895f9
65b7ecac7bd4346fae8f49764b0d6d2eb8de39ae
ml/backend/ggml: fix library loading on macOS amd64 (#8827)
[ { "path": "CMakeLists.txt", "patch": "@@ -29,6 +29,11 @@ if((NOT CMAKE_OSX_ARCHITECTURES MATCHES \"arm64\")\n set(GGML_CPU_ALL_VARIANTS ON)\n endif()\n \n+if (CMAKE_OSX_ARCHITECTURES MATCHES \"x86_64\")\n+ set(CMAKE_BUILD_RPATH \"@loader_path\")\n+ set(CMAKE_INSTALL_RPATH \"@loader_path\")\n+endif...
2025-02-04T23:05:39
golang/go
80344887818a2321296ce7fa71cca8ca2520611d
53b2b64b649b26c7bb3397bec5d86d3b203eb015
os: sysctl-based Executable implementation for NetBSD FreeBSD and Dragonfly have used the sysctl method for years, while NetBSD has read the name of the executable from /proc. Unfortunately, some folks are hitting errors when building Go software in a sandbox that lacks a mounted /proc filesystem. Switch NetBSD to us...
[ { "path": "src/os/executable_dragonfly.go", "patch": "@@ -10,3 +10,5 @@ const (\n \t_KERN_PROC = 14\n \t_KERN_PROC_PATHNAME = 9\n )\n+\n+var executableMIB = [4]int32{_CTL_KERN, _KERN_PROC, _KERN_PROC_PATHNAME, -1}", "additions": 2, "deletions": 0, "language": "Go" }, { "path": "...
2024-11-18T12:43:58
vuejs/vue
fb1393009660b38046b1f6dfb532b481cc53b3b7
87f69aa26f195390b948fbb0ff62cf954b58c82c
fix(sfc): prune returned bindings for non-TS as well In Vue 3, pruning is only done for TS to produce valid code and tree-shaking is done by inlining the template for production. In Vue 2 we do not inline the template in production, so return binding pruning is needed in all cases. fix #12765
[ { "path": "packages/compiler-sfc/src/compileScript.ts", "patch": "@@ -284,11 +284,9 @@ export function compileScript(\n userImportAlias[imported] = local\n }\n \n- // template usage check is only needed in non-inline mode, so we can skip\n- // the work if inlineTemplate is true.\n let is...
2022-10-11T06:09:10
huggingface/transformers
78bb85146c59258a0710c8d08311d98d52303c38
8c403da7ae37d20314d00d940d96c4a27fc98a29
Fix `process_bad_commit_report.py`: avoid items to appear in `null` author in the report (#43662) fix Co-authored-by: ydshieh <ydshieh@users.noreply.github.com>
[ { "path": "utils/process_bad_commit_report.py", "patch": "@@ -105,7 +105,8 @@\n for failed_test in failed_tests:\n author = failed_test[\"author\"]\n \n- if author not in team_members:\n+ # If author is not a team member, and the PR is already merged...
2026-01-31T21:45:59
ggml-org/llama.cpp
5a32a9b8a5bddf3c6234fd2eb17b0a7315328f93
3b439504ba49d41c75885d34c1353d195e09e028
Fix data race in CUDA's "cpy" kernel (influences GGML's DUP, CONT operations). (#20507) * Fix datarace in CUDA's "cpy" kernel. * Remove extra barrier by using more of shared memory.
[ { "path": "ggml/src/ggml-cuda/cpy.cu", "patch": "@@ -56,7 +56,8 @@ static __global__ void cpy_scalar_transpose(const char * cx, char * cdst, const\n const int tx = blockIdx.y * CUDA_CPY_TILE_DIM_2D + threadIdx.x; // transpose block offset\n const int ty = blockIdx.x * CUDA_CPY_TILE_DIM_2D + threadI...
2026-03-14T05:19:44
ollama/ollama
65b7ecac7bd4346fae8f49764b0d6d2eb8de39ae
f9d2d8913554d78b1cae47c5eaa9cbbd0ea79273
fix extra quote
[ { "path": ".github/workflows/release.yaml", "patch": "@@ -408,7 +408,7 @@ jobs:\n working-directory: dist\n - name: Create or update Release\n run: |\n- RELEASE_VERSION=$(echo ${GITHUB_REF_NAME} | cut -f1 -d-)\"\n+ RELEASE_VERSION=\"$(echo ${GITHUB_REF_NAME} | cut -f1...
2025-02-04T02:19:17
golang/go
53b2b64b649b26c7bb3397bec5d86d3b203eb015
5a0f2a7a7c5658f4f3065c265cee61ec1bde9691
sync: add explicit noCopy fields to Map, Mutex, and Once Following CLs will refactor Mutex and change the internals of Map. This ends up breaking tests in x/tools for the copylock vet check, because the error message changes. Let's insulate ourselves from such things permanently by adding an explicit noCopy field. We'...
[ { "path": "src/sync/map.go", "patch": "@@ -36,6 +36,8 @@ import (\n //\n // [the Go memory model]: https://go.dev/ref/mem\n type Map struct {\n+\t_ noCopy\n+\n \tmu Mutex\n \n \t// read contains the portion of the map's contents that are safe for", "additions": 2, "deletions": 0, "language": "Go...
2024-11-15T19:22:16
huggingface/transformers
8c403da7ae37d20314d00d940d96c4a27fc98a29
172216339fcac65e049d011a06ff46c962a7d002
Fix `KeyError` in `check_bad_commit.py` (#43655) fix Co-authored-by: ydshieh <ydshieh@users.noreply.github.com>
[ { "path": "utils/check_bad_commit.py", "patch": "@@ -279,7 +279,7 @@ def get_commit_info(commit, pr_number=None):\n \n # TODO: make this script able to deal with both `single-gpu` and `multi-gpu` via a new argument.\n reports[model].pop(\"multi-gpu\", None)\n- failed_tests...
2026-01-31T18:50:57
vuejs/vue
87f69aa26f195390b948fbb0ff62cf954b58c82c
5d26f815c643d41e6ca6f29329593223b981fc24
fix(types): support Ref and function types in tsx ref attribute (#12759) fix #12758
[ { "path": "types/test/v3/tsx-test.tsx", "patch": "@@ -1,4 +1,4 @@\n-import { VNode, defineComponent } from '../../index'\n+import { VNode, defineComponent, ref } from '../../index'\n import { expectType } from '../utils'\n \n expectType<VNode>(<div />)\n@@ -22,6 +22,11 @@ expectError(<div foo=\"bar\" />)\n ...
2022-10-11T05:36:50
ggml-org/llama.cpp
3b439504ba49d41c75885d34c1353d195e09e028
463b6a963c2de376e102d878a50d26802f15833c
opencl: fix l2_norm (#20480)
[ { "path": "ggml/src/ggml-opencl/kernels/l2_norm.cl", "patch": "@@ -63,7 +63,7 @@ kernel void kernel_l2_norm_f32(\n \n barrier(CLK_LOCAL_MEM_FENCE);\n \n- const float scale = 1.0f/sqrt(max(sum[0], eps));\n+ const float scale = 1.0f/max(sqrt(sum[0]), eps);\n \n for (int i00 = get_local_id(0); i0...
2026-03-14T05:18:52
ollama/ollama
f9d2d8913554d78b1cae47c5eaa9cbbd0ea79273
669dc31cf33a1d167dbbe5398e3e2ec71620bcef
fix linux archive
[ { "path": ".github/workflows/release.yaml", "patch": "@@ -326,7 +326,7 @@ jobs:\n PLATFORM: ${{ matrix.os }}/${{ matrix.arch }}\n - uses: actions/upload-artifact@v4\n with:\n- name: dist-${{ matrix.os }}-${{ matrix.arch }}\n+ name: dist-${{ matrix.os }}-${{ matrix.a...
2025-02-03T23:12:54
golang/go
bcdaac63965473ce315681a7af7e169b741a01e1
7a20239ce8a877ae82b8c269a8ff28fe59609c69
runtime: fix MapCycle test It wasn't actually testing what it says it was testing. A random permutation isn't cyclic. It only probably hits a few elements before entering a cycle. Use an algorithm that generates a random cyclic permutation instead. Fixing the test makes the previous CL look less good. But it still he...
[ { "path": "src/runtime/map_benchmark_test.go", "patch": "@@ -258,12 +258,41 @@ func BenchmarkMapLast(b *testing.B) {\n \t}\n }\n \n+func cyclicPermutation(n int) []int {\n+\t// From https://crypto.stackexchange.com/questions/51787/creating-single-cycle-permutations\n+\tp := rand.New(rand.NewSource(1)).Perm(...
2024-11-08T23:48:33
huggingface/transformers
172216339fcac65e049d011a06ff46c962a7d002
2ff1d4f0eced8037c1cf5bfb8ff9a40ce241cbcf
[Benchmark] Minor fix for benchmark: kernel is not correctly called (#43428) * benchmark-v2: minor fix for benchmark-v2, kernel is not correctly called Signed-off-by: Wang, Yi <yi.a.wang@intel.com> * update Signed-off-by: Wang, Yi <yi.a.wang@intel.com> * update format Signed-off-by: Wang, Yi <yi.a.wang@intel.com>...
[ { "path": "benchmark_v2/framework/benchmark_config.py", "patch": "@@ -40,13 +40,15 @@ def is_fa2_or_kernel_available() -> bool:\n try:\n from kernels import get_kernel\n \n- get_kernel(\"kernels-community/flash-attn\")\n+ # TODO: Pass the 'version' kwarg to specify the binary versi...
2026-01-31T13:48:54
ggml-org/llama.cpp
1430c35948db08a35ba07ff3c2709bd50d58f563
f17b3be63fd9dfa3d12ad3555c977a6430661769
common/parser: gracefully handle undetected tool parser, print error message. (#20286)
[ { "path": "common/chat-auto-parser-generator.cpp", "patch": "@@ -3,6 +3,7 @@\n #include \"chat.h\"\n #include \"common.h\"\n #include \"json-schema-to-grammar.h\"\n+#include \"log.h\"\n #include \"nlohmann/json.hpp\"\n \n #include <stdexcept>\n@@ -182,7 +183,10 @@ common_peg_parser analyze_tools::build_pars...
2026-03-13T19:56:10
vuejs/vue
5d26f815c643d41e6ca6f29329593223b981fc24
4a0d88e46e4180edc7f22e36c25df3f8ac5d60d2
fix(reactivity): check skip first before checking ref when creating observer (#12813) fix #12812
[ { "path": "src/core/observer/index.ts", "patch": "@@ -7,7 +7,6 @@ import {\n hasOwn,\n isArray,\n hasProto,\n- isObject,\n isPlainObject,\n isPrimitive,\n isUndef,\n@@ -108,23 +107,21 @@ export function observe(\n shallow?: boolean,\n ssrMockReactivity?: boolean\n ): Observer | void {\n- i...
2022-10-11T05:26:20
electron/electron
30e0620ccc1a586358b2802a8bf08ada754c5506
b61805b63a32b70a3d6d0bef4cc58c580ff8ea38
docs: fix wording on testing documentation (#32279)
[ { "path": "docs/development/testing.md", "patch": "@@ -22,7 +22,7 @@ you error would be caught at commit time.\n ## Unit Tests\n \n If you are not using [build-tools](https://github.com/electron/build-tools),\n-ensure that that name you have configured for your\n+ensure that the name you have configured for...
2022-01-06T00:24:52
huggingface/transformers
2ff1d4f0eced8037c1cf5bfb8ff9a40ce241cbcf
5a67f0a7aca8c18de6235e80e47fd00a9ecf9d58
Add explicit commit info to PR comment CI feedback (#43635) * fix * fix * fix * fix --------- Co-authored-by: ydshieh <ydshieh@users.noreply.github.com>
[ { "path": ".github/workflows/check_failed_tests.yml", "patch": "@@ -177,6 +177,7 @@ jobs:\n env:\n job: ${{ inputs.job }}\n run_idx: ${{ matrix.run_idx }}\n+ pr_number: ${{ inputs.pr_number }}\n run: python3 utils/check_bad_commit.py --start_commit \"$START_SHA\"...
2026-01-31T11:33:49
ollama/ollama
669dc31cf33a1d167dbbe5398e3e2ec71620bcef
d4d338c2248ad015334e7b94c4ddb8cc744083a2
fix build
[ { "path": ".github/workflows/release.yaml", "patch": "@@ -273,6 +273,8 @@ jobs:\n merge-multiple: true\n - run: |\n & .\\scripts\\build_windows.ps1 gatherDependencies sign buildInstaller distZip\n+ env:\n+ KEY_CONTAINER: ${{ vars.KEY_CONTAINER }}\n - uses: act...
2025-02-03T21:31:22
golang/go
7a20239ce8a877ae82b8c269a8ff28fe59609c69
5ec1457941d1754a583a745259b9c308749c0bd1
crypto/subtle: document and test XORBytes overlap rules XORBytes doesn't say anything about how it deals with destination and source overlaps. Current implementations as written do work if the destination overlaps perfectly with a source, but will unavoidably return nonsensical results if the destination is ahead of t...
[ { "path": "src/crypto/internal/fips/subtle/xor.go", "patch": "@@ -4,10 +4,16 @@\n \n package subtle\n \n+import \"crypto/internal/fips/alias\"\n+\n // XORBytes sets dst[i] = x[i] ^ y[i] for all i < n = min(len(x), len(y)),\n // returning n, the number of bytes written to dst.\n+//\n // If dst does not have ...
2024-10-24T14:27:44
ggml-org/llama.cpp
f17b3be63fd9dfa3d12ad3555c977a6430661769
d7ba99c4850bd687621f13329490dc28f28f17c9
llama : fix pooling assertion crash in chunked GDN detection path (#20468) * llama : fix pooling assertion crash in chunked GDN detection path The chunked fused Gated Delta Net detection in sched_reserve() calls graph_reserve(16*n_seqs, n_seqs, n_outputs, ...) where n_outputs = n_seqs. This creates a dimension mismat...
[ { "path": "src/llama-context.cpp", "patch": "@@ -512,7 +512,12 @@ void llama_context::sched_reserve() {\n \n if (cparams.fused_gdn_ch) {\n // more than one token in the batch per sequence in order to take the chunked path\n- auto * gf = graph_reserve(16*n_seqs, n_seqs, n_outpu...
2026-03-13T18:53:42
vuejs/vue
4a0d88e46e4180edc7f22e36c25df3f8ac5d60d2
27eed829ccf9978a63b8cd989ff4c03897276bc2
fix(reactivity): use WeakMap for proxy/raw checks, compat with non-extensible objects fix #12799 close #12798
[ { "path": "src/core/observer/index.ts", "patch": "@@ -17,6 +17,7 @@ import {\n noop\n } from '../util/index'\n import { isReadonly, isRef, TrackOpTypes, TriggerOpTypes } from '../../v3'\n+import { rawMap } from '../../v3/reactivity/reactive'\n \n const arrayKeys = Object.getOwnPropertyNames(arrayMethods)\...
2022-10-11T04:26:19
electron/electron
b61805b63a32b70a3d6d0bef4cc58c580ff8ea38
dd4eae8a3b7f707bcd3d083d553988a29e332189
fix: use allocationtype kold in v8 scriptormodule legacy lifetime (#32339)
[ { "path": "patches/v8/.patches", "patch": "@@ -6,3 +6,4 @@ workaround_an_undefined_symbol_error.patch\n do_not_export_private_v8_symbols_on_windows.patch\n fix_build_deprecated_attirbute_for_older_msvc_versions.patch\n fix_disable_implies_dcheck_for_node_stream_array_buffers.patch\n+fix_use_allocationtype_k...
2022-01-05T19:43:28
golang/go
5ec1457941d1754a583a745259b9c308749c0bd1
61790207f52fb594aeb5cd71c1ef62051bc177f9
cmd/compile: avoid static init of strings in FIPS mode Strings have relocations, and data relocations are bad. Other literals are fine. Fixes build failure in pending CL 628776. Change-Id: I7a38bbff9776a365c5823d54c4a00e068dda5d9a Reviewed-on: https://go-review.googlesource.com/c/go/+/628915 Reviewed-by: Cuong Manh ...
[ { "path": "src/cmd/compile/internal/staticinit/sched.go", "patch": "@@ -332,6 +332,9 @@ func (s *Schedule) StaticAssign(l *ir.Name, loff int64, r ir.Node, typ *types.Ty\n \t\tif ir.IsZero(r) {\n \t\t\treturn true\n \t\t}\n+\t\tif disableGlobalAddrs && r.Type().IsString() {\n+\t\t\treturn false\n+\t\t}\n \t\...
2024-11-18T00:53:18
ollama/ollama
e8061840235bb953d621796b7d65e86541dbc0a1
50566113ace20bad141859710e2f2689248324b4
fix release workflow
[ { "path": ".github/workflows/release.yaml", "patch": "@@ -81,7 +81,7 @@ jobs:\n path: dist/darwin-arm64\n - run: |\n export VERSION=${GITHUB_REF_NAME#v}\n- ./scripts/build_darwin.sh macapp sign\n+ ./scripts/build_darwin.sh sign macapp\n env:\n AP...
2025-02-01T00:19:41
huggingface/transformers
94848a1328d151b1accb182bd5ab32d73d0ce0bc
16eca6b5d2067975e1ecb7a3283cda6593100fae
[docs] serving (#42853) * split serving docs * update * split * fix links
[ { "path": "docs/source/en/_toctree.yml", "patch": "@@ -116,16 +116,18 @@\n title: Writing a chat template\n title: Chat with models\n - sections:\n- - local: serving\n- title: Serving LLMs, VLMs, and other chat-based models\n- - local: jan\n- title: Jan\n- - local: cursor\n+ ...
2026-01-30T17:45:21
ggml-org/llama.cpp
d7ba99c4850bd687621f13329490dc28f28f17c9
fbaa95bc29b9005586b76ab3d74f485eec05f282
server: reset counter related to kill-switch on client error (#20513) * server: reset kill-switch on client error This avoids triggering a server kill switch. If the client sends a request that exceeds the configured context size, an appropriate HTTP 400 response is provided and no tokens are generated. However sin...
[ { "path": "tools/server/server-context.cpp", "patch": "@@ -1189,6 +1189,9 @@ struct server_context_impl {\n ? SLOT_STATE_WAIT_OTHER // wait for the parent to process prompt\n : SLOT_STATE_STARTED;\n \n+ // reset server kill-switch counter\n+ n_empty_consecutive = 0;\n+\...
2026-03-13T17:58:09
vuejs/vue
27eed829ccf9978a63b8cd989ff4c03897276bc2
2f335b2f9d09b962f40e38740826d444e4fff073
fix(types): vue 3 directive type compatibility (#12792)
[ { "path": "types/options.d.ts", "patch": "@@ -4,6 +4,7 @@ import { SetupContext } from './v3-setup-context'\n import { DebuggerEvent } from './v3-generated'\n import { DefineComponent } from './v3-define-component'\n import { ComponentOptionsMixin } from './v3-component-options'\n+import { ObjectDirective, ...
2022-10-11T03:51:05
electron/electron
cbdb2e6ec2fae7749b7ebf0a3488ce702493b320
84f1d78558cb2cf6765191299c9b03ad59c0e6b4
fix: #32141 register wrong command for setAsDefaultProtocolClient for windows (#32220)
[ { "path": "shell/browser/browser_win.cc", "patch": "@@ -66,7 +66,7 @@ bool GetProtocolLaunchPath(gin::Arguments* args, std::wstring* exe) {\n // Read in optional args arg\n std::vector<std::wstring> launch_args;\n if (args->GetNext(&launch_args) && !launch_args.empty())\n- *exe = base::StringPrintf...
2022-01-04T01:47:28
ollama/ollama
50566113ace20bad141859710e2f2689248324b4
ad22ace439eb3fab7230134e56bb6276a78347e4
llm: do not error if LibOllamaPath does not exist (#8801)
[ { "path": "llm/server.go", "patch": "@@ -89,7 +89,6 @@ func LoadModel(model string, maxArraySize int) (*GGML, error) {\n // NewLlamaServer will run a server for the given GPUs\n // The gpu list must be a single family.\n func NewLlamaServer(gpus discover.GpuInfoList, model string, ggml *GGML, adapters, proj...
2025-02-03T20:27:48
golang/go
e64f7ef03fdfa1c0d847c21b16c9302cc824e79b
5a529e06c153141e7a2508c0b3c3f5f7a631a188
net/http/httputil: return after handling error Fixes #70237 Change-Id: Ieb22b6e7284cb4a40d4987b0e4b9cfb6e5158161 Reviewed-on: https://go-review.googlesource.com/c/go/+/627635 LUCI-TryBot-Result: Go LUCI <golang-scoped@luci-project-accounts.iam.gserviceaccount.com> Reviewed-by: Dmitri Shuralyov <dmitshur@google.com> A...
[ { "path": "src/net/http/httputil/reverseproxy.go", "patch": "@@ -739,6 +739,7 @@ func (p *ReverseProxy) handleUpgradeResponse(rw http.ResponseWriter, req *http.R\n \tresUpType := upgradeType(res.Header)\n \tif !ascii.IsPrint(resUpType) { // We know reqUpType is ASCII, it's checked by the caller.\n \t\tp.get...
2024-11-13T18:54:54
ggml-org/llama.cpp
b5e1212063e3a605bd421c0edfee1a4a59731f65
8f974d2392da4e6fa422a67050e90f1471d72966
ggml : fix typo gmml (#20512) Signed-off-by: Adrien Gallouët <angt@huggingface.co>
[ { "path": "ggml/CMakeLists.txt", "patch": "@@ -253,7 +253,7 @@ option(GGML_OPENCL_PROFILING \"ggml: use OpenCL profiling (increas\n option(GGML_OPENCL_EMBED_KERNELS \"ggml: embed kernels\" ON)\n option(GGML_OPENCL_USE_ADRENO_KERNELS \"ggml: use opt...
2026-03-13T13:36:13
vuejs/vue
2f335b2f9d09b962f40e38740826d444e4fff073
60d268c4261a0b9c5125f308468b31996a8145ad
fix(sfc): remove sfc scoped deep syntax deprecation warnings
[ { "path": "packages/compiler-sfc/src/stylePlugins/scoped.ts", "patch": "@@ -1,6 +1,5 @@\n import { PluginCreator, Rule, AtRule } from 'postcss'\n import selectorParser from 'postcss-selector-parser'\n-import { warn } from '../warn'\n \n const animationNameRE = /^(-\\w+-)?animation-name$/\n const animationRE...
2022-10-11T03:41:31
electron/electron
84f1d78558cb2cf6765191299c9b03ad59c0e6b4
4600d7e7f659092e31ca125f2a871067802ac14f
docs: correct webFrame description (#32205) The current description incorrectly states that the webFrame export represents the top frame but it actually represents the current frame.
[ { "path": "docs/api/web-frame.md", "patch": "@@ -5,8 +5,8 @@\n Process: [Renderer](../glossary.md#renderer-process)\n \n `webFrame` export of the Electron module is an instance of the `WebFrame`\n-class representing the top frame of the current `BrowserWindow`. Sub-frames can\n-be retrieved by certain prope...
2022-01-04T01:12:55
huggingface/transformers
255c62a18ab9bc923693ebea9d7924f23bb6d365
11b9b0f5b52f82b42ff075ccbe2afffa85ecff8d
Allow Attention and Experts to be used as standalone modules (#43622) * default * fix all * fix * add warning * strict check * fix * add test * fix * improve test
[ { "path": "examples/modular-transformers/modeling_dummy_bert.py", "patch": "@@ -169,9 +169,9 @@ def forward(\n {\"cache_position\": cache_position},\n )\n \n- attention_interface: Callable = eager_attention_forward\n- if self.config._attn_implementation != \"eager\"...
2026-01-30T16:35:30
ollama/ollama
475333d533e088538e5d77c0ba65ea60833b2c77
39fd89308c0bbe26311db583cf9729f81ffa9a94
fix docker build-args env context is not accessible from job.*.strategy. since it's in the environment, just tell docker to use the environment variable[1] [1]: https://docs.docker.com/reference/cli/docker/buildx/build/#build-arg
[ { "path": ".github/workflows/release.yaml", "patch": "@@ -312,16 +312,18 @@ jobs:\n - flavor: 'latest=false'\n platforms: linux/amd64,linux/arm64\n build-args: |\n- CGO_CFLAGS=${{ env.CGO_CFLAGS }}\n- CGO_CXXFLAGS=${{ env.CGO_CXXFLAGS }}\n- ...
2025-01-31T22:25:49
golang/go
44b2ba721ba53efdc72fb2970d57ea75da6e0158
1fba1f60620d386c4754814d462c6482226431b0
cmd/go: fix TestScript/build_json on Windows The file system directory separator affects this test's output. Fixes #70397. Cq-Include-Trybots: luci.golang.try:gotip-windows-amd64-longtest,gotip-linux-amd64-longtest Change-Id: Id8a3f3e1c26c94ea8f635df4e62e7b0cc2cd5515 Reviewed-on: https://go-review.googlesource.com/c...
[ { "path": "src/cmd/go/testdata/script/build_json.txt", "patch": "@@ -3,7 +3,7 @@\n # Basic build error. This test also checks that the output is fully-formed JSON.\n ! go build -json -o=$devnull ./compileerror\n stdout '^\\{\"ImportPath\":\"m/compileerror\",\"Action\":\"build-output\",\"Output\":\"# m/compi...
2024-11-18T03:18:02
vuejs/vue
e0b26c483a1ba407a818b1fcba1a439df24e84a8
46ca7bcddc06c50796ccff82d8c45693f1f14f47
fix: fix parent of multi-nested HOC $el not updating (#12757) fix #12589
[ { "path": "src/core/instance/lifecycle.ts", "patch": "@@ -83,8 +83,15 @@ export function lifecycleMixin(Vue: typeof Component) {\n vm.$el.__vue__ = vm\n }\n // if parent is an HOC, update its $el as well\n- if (vm.$vnode && vm.$parent && vm.$vnode === vm.$parent._vnode) {\n- vm.$parent...
2022-08-23T01:22:45
ggml-org/llama.cpp
73c9eb8ceda397b651dbb6661b2935f0283a2b1d
983df142a99b764f5cbe9acb6b9ec862f861d353
metal : fix l2 norm scale (#20493)
[ { "path": "ggml/src/ggml-metal/ggml-metal-device.m", "patch": "@@ -1156,7 +1156,7 @@ bool ggml_metal_device_supports_op(ggml_metal_device_t dev, const struct ggml_te\n case GGML_OP_RWKV_WKV7:\n return true;\n case GGML_OP_GATED_DELTA_NET:\n- return op->src[2]->ne[0] % ...
2026-03-13T09:43:20
electron/electron
4600d7e7f659092e31ca125f2a871067802ac14f
2c700da4de0031d2e620f77b1415613eaf335793
fix: crash caused by app.getLocaleCountryCode() (#32256) CFLocaleGetValue() returned null and crashed the process when app.getLocaleCountryCode() was run on a CircleCI metal resource class macOS instance with Xcode 12.5.1. This change fixes that logic and adds further checks to make the code future-proof. Here t...
[ { "path": "shell/browser/api/electron_api_app.cc", "patch": "@@ -1054,11 +1054,14 @@ std::string App::GetLocaleCountryCode() {\n CFLocaleRef locale = CFLocaleCopyCurrent();\n CFStringRef value = CFStringRef(\n static_cast<CFTypeRef>(CFLocaleGetValue(locale, kCFLocaleCountryCode)));\n- const CFInd...
2022-01-03T21:54:58
huggingface/transformers
11b9b0f5b52f82b42ff075ccbe2afffa85ecff8d
4bb0a8691b0b78ba9e7602a3e94f5371abe5c441
Don't modify `tied_weight_keys` in-place (#43619) * fix * these mmodels modify in-place, add a test * fix repo * tiny comment
[ { "path": "src/transformers/modeling_utils.py", "patch": "@@ -1314,9 +1314,11 @@ def __init__(self, config: PreTrainedConfig, *inputs, **kwargs):\n self.warnings_issued = {}\n # Overwrite the class attribute to make it an instance attribute, so models like\n # `InstructBlipForConditi...
2026-01-30T15:46:01
vuejs/vue
46ca7bcddc06c50796ccff82d8c45693f1f14f47
810f6d12edea47cde7f39eaf7ec3ae1b7300d40c
fix(compiler-sfc): avoid deindent when lang is jsx/tsx fix #12755
[ { "path": "packages/compiler-sfc/src/parseComponent.ts", "patch": "@@ -179,11 +179,11 @@ export function parseComponent(\n let text = source.slice(currentBlock.start, currentBlock.end)\n if (\n options.deindent === true ||\n- // by default, deindent unless it's script with default...
2022-08-23T01:18:36
golang/go
1fba1f60620d386c4754814d462c6482226431b0
2779e3a4530451959313a1a87787e8eb4f80ef1c
text/template: don't crash piping to call with no arguments Fixes #70341 Change-Id: I792b15d5e8d08c3762659fbcdfb3d620b59071ca Reviewed-on: https://go-review.googlesource.com/c/go/+/628096 LUCI-TryBot-Result: Go LUCI <golang-scoped@luci-project-accounts.iam.gserviceaccount.com> Reviewed-by: Ian Lance Taylor <iant@goog...
[ { "path": "src/text/template/exec.go", "patch": "@@ -856,7 +856,13 @@ func (s *state) evalCall(dot, fun reflect.Value, isBuiltin bool, node parse.Node\n \t// Special case for the \"call\" builtin.\n \t// Insert the name of the callee function as the first argument.\n \tif isBuiltin && name == \"call\" {\n-\...
2024-11-14T17:17:15
ollama/ollama
5d75d837efc9315c19f538f2b2130baf5fbc242a
711648c9bbc186697c19775bf140b174b6a5687a
discover: fix default LibOllamaPath value (#8702)
[ { "path": "discover/path.go", "patch": "@@ -24,30 +24,34 @@ var LibOllamaPath string = func() string {\n \t\treturn \"\"\n \t}\n \n-\tlibPath := filepath.Dir(exe)\n+\tvar libPath string\n \tswitch runtime.GOOS {\n \tcase \"windows\":\n \t\tlibPath = filepath.Join(filepath.Dir(exe), \"lib\", \"ollama\")\n \t...
2025-01-30T20:21:38
electron/electron
2c700da4de0031d2e620f77b1415613eaf335793
195d2b5b3ef88d36f0afbb4a811c86951106862b
docs: add Bugsnag as a 3rd party crash server (#32053)
[ { "path": "docs/api/crash-reporter.md", "patch": "@@ -27,6 +27,7 @@ Or use a 3rd party hosted solution:\n * [Backtrace](https://backtrace.io/electron/)\n * [Sentry](https://docs.sentry.io/clients/electron)\n * [BugSplat](https://www.bugsplat.com/docs/platforms/electron)\n+* [Bugsnag](https://docs.bugsnag.co...
2022-01-03T19:48:15
vuejs/vue
810f6d12edea47cde7f39eaf7ec3ae1b7300d40c
15618888cb6aae2b6f0151b32c261b1fc19db1b8
fix(types): Add missing type parameter constraints (#12754)
[ { "path": "types/options.d.ts", "patch": "@@ -95,8 +95,8 @@ export type ThisTypedComponentOptionsWithArrayProps<\n Computed,\n PropNames extends string,\n SetupBindings,\n- Mixin,\n- Extends\n+ Mixin extends ComponentOptionsMixin,\n+ Extends extends ComponentOptionsMixin\n > = object &\n Compone...
2022-08-22T02:28:39
huggingface/transformers
4bb0a8691b0b78ba9e7602a3e94f5371abe5c441
de4958ebaba3673d98e931fd9471643ece2fb0ff
[`Rope`] Revert #43410 and make inheritance implicit again (#43620) * fix * fix
[ { "path": "src/transformers/configuration_utils.py", "patch": "@@ -27,6 +27,7 @@\n from .dynamic_module_utils import custom_object_save\n from .generation.configuration_utils import GenerationConfig\n from .modeling_gguf_pytorch_utils import load_gguf_checkpoint\n+from .modeling_rope_utils import RotaryEmbe...
2026-01-30T15:43:32
electron/electron
195d2b5b3ef88d36f0afbb4a811c86951106862b
727453ef04042cfce0dae5d42535d9728c3c9d2d
[fix] Docs rendering issue with rendering on electronjs quick-start (#32293) there is a issue with rendering on the bottom of page https://www.electronjs.org/docs/v14-x-y/tutorial/quick-start which looks like this ![](https://dl3.pushbulletusercontent.com/MXsLhjaoKRj1bhu4R73E3WLiuKCBMkgh/image.png) all id did is ...
[ { "path": "docs/tutorial/quick-start.md", "patch": "@@ -463,46 +463,46 @@ The fastest way to distribute your newly created app is using\n 1. Add Electron Forge as a development dependency of your app, and use its `import` command to set up\n Forge's scaffolding:\n \n- ```sh npm2yarn\n- npm install --s...
2022-01-03T19:18:02
ggml-org/llama.cpp
983df142a99b764f5cbe9acb6b9ec862f861d353
57819b8d4b39d893408e51520dff3d47d1ebb757
convert : fix/suppress pyright errors (#20442) * convert : fix/suppress pyright errors This commit fixes the pyright errors that are generated by pyright for convert_hf_to_gguf.py. The motivation for this is that running this locally generates errors that CI does not, and it can be difficult to spot new errors. One ...
[ { "path": "convert_hf_to_gguf.py", "patch": "@@ -2194,6 +2194,8 @@ def set_gguf_parameters(self):\n def modify_tensors(self, data_torch: Tensor, name: str, bid: int | None) -> Iterable[tuple[str, Tensor]]:\n n_head = self.hparams.get(\"n_head\", self.hparams.get(\"num_attention_heads\"))\n ...
2026-03-13T05:00:52
vuejs/vue
8521f9d3f63d26bde99b747f0cb14d0ac5ba5971
7161176cd0dff10d65ab58e266018aff2660610f
fix(types): fix missing error for accessing undefined instance properties fix #12718
[ { "path": "types/test/v3/define-component-test.tsx", "patch": "@@ -1166,6 +1166,62 @@ defineComponent({\n }\n })\n \n-// #12742 allow attaching custom properties (consistent with v3)\n-const Foo = defineComponent({})\n-Foo.foobar = 123\n+describe('constructor attach custom properties', () => {\n+ // #127...
2022-08-19T04:22:51
huggingface/transformers
de4958ebaba3673d98e931fd9471643ece2fb0ff
eaab9f2fdedf450de24d46e2e2bb63f12e373349
[vllm compat] Separate renaming from conversion ops (#43621) * switch mapping to test poc * fix * more * fix * comment * oupsi
[ { "path": "src/transformers/conversion_mapping.py", "patch": "@@ -85,13 +85,13 @@ def _build_checkpoint_conversion_mapping():\n ),\n ],\n \"mixtral\": [\n- WeightRenaming(\".block_sparse_moe.gate\", \".mlp.gate\"),\n+ WeightRenaming(\".block_sparse_moe.\", \...
2026-01-30T15:37:22
ollama/ollama
dcfb7a105c455ae8d44a06b3380731d8b1ffcc22
2ef3c803a151a0a9b1776c9ebe6a7e86b3971660
next build (#8539) * add build to .dockerignore * test: only build one arch * add build to .gitignore * fix ccache path * filter amdgpu targets * only filter if autodetecting * Don't clobber gpu list for default runner This ensures the GPU specific environment variables are set properly * explicitly set CXX co...
[ { "path": ".dockerignore", "patch": "@@ -3,7 +3,9 @@ ollama\n app\n macapp\n dist\n+build\n .env\n .cache\n test_data\n-llama/build\n+.git\n+", "additions": 3, "deletions": 1, "language": "Unknown" }, { "path": ".gitattributes", "patch": "@@ -7,5 +7,14 @@ llama/**/*.cuh linguist-vend...
2025-01-29T23:03:38
electron/electron
f766bb483daf644633f0f2b753317d25fc7e1c5b
1d8612ad5d7d74ba39908ee565a9457dd573ef84
docs: fix typo in bug report issue template (#32208)
[ { "path": ".github/ISSUE_TEMPLATE/bug_report.yml", "patch": "@@ -12,7 +12,7 @@ body:\n required: true\n - label: I agree to follow the [Code of Conduct](https://github.com/electron/electron/blob/main/CODE_OF_CONDUCT.md) that this project adheres to.\n required: true\n- - label: I ...
2022-01-03T09:35:19
golang/go
90b1dc0192b62e4007031cf8b472023da08f7ca7
d1180dbd5e5728d268e0dda01fd2daa261911ec8
internal/runtime/maps: fix noswiss builder Missed initializing a field in the stub that lets the noswiss builder test the swiss implementation. Change-Id: Ie093478ad3e4301e4fe88ba65c132a9dbccd89a9 Reviewed-on: https://go-review.googlesource.com/c/go/+/628895 Auto-Submit: Keith Randall <khr@golang.org> Reviewed-by: Ch...
[ { "path": "src/internal/runtime/maps/export_noswiss_test.go", "patch": "@@ -33,12 +33,13 @@ func newTestMapType[K comparable, V any]() *abi.SwissMapType {\n \tvar slot instantiatedSlot[K, V]\n \n \tmt := &abi.SwissMapType{\n-\t\tKey: omt.Key,\n-\t\tElem: omt.Elem,\n-\t\tGroup: abi.TypeOf(grp),\n...
2024-11-17T21:24:43
vuejs/vue
7161176cd0dff10d65ab58e266018aff2660610f
165a14a6c6c406176037465d2961259c5c980399
fix: fix effect scope tracking for manually created instances fix #12705
[ { "path": "src/core/instance/init.ts", "patch": "@@ -34,6 +34,7 @@ export function initMixin(Vue: typeof Component) {\n vm.__v_skip = true\n // effect scope\n vm._scope = new EffectScope(true /* detached */)\n+ vm._scope._vm = true\n // merge options\n if (options && options._isCompon...
2022-08-18T10:14:50
ggml-org/llama.cpp
128142fe7dd02cc87e178778ae80affcc8836304
6de1bc631d1a27e1f71fef2e6f8fad4ea3f5cf67
test-backend-ops: allow loading tests from file and parsing model operators into file (#19896) * tests: allow loading test-backend-ops tests from json * add error threshold based on op * add error when file cannot be read * add graph operator json extraction tool * add nb parameter for non-contiguous input tensors...
[ { "path": "common/arg.cpp", "patch": "@@ -2671,7 +2671,8 @@ common_params_context common_params_parser_init(common_params & params, llama_ex\n [](common_params & params, const std::string & value) {\n params.out_file = value;\n }\n- ).set_examples({LLAMA_EXAMPLE_IMATRIX, LLAMA...
2026-03-12T12:26:00
ollama/ollama
a420a453b4783841e3e79c248ef0fe9548df6914
42cf4db6017a949c2decd1bb9b6cac2468aceeaf
fix default modelfile for create (#8452)
[ { "path": "cmd/cmd.go", "patch": "@@ -59,7 +59,7 @@ func getModelfileName(cmd *cobra.Command) (string, error) {\n \n \t_, err = os.Stat(absName)\n \tif err != nil {\n-\t\treturn filename, err\n+\t\treturn \"\", err\n \t}\n \n \treturn absName, nil", "additions": 1, "deletions": 1, "language": "G...
2025-01-16T09:14:04
electron/electron
1d8612ad5d7d74ba39908ee565a9457dd573ef84
ac39cb14e9eb91441d060e6820d1957ee7a40f19
Fix typo in quick-start.md (#32282) Resolve a grammar issue in the quick-start guide.
[ { "path": "docs/tutorial/quick-start.md", "patch": "@@ -119,7 +119,7 @@ of your project.\n \n Before we can create a window for our application, we need to create the content that\n will be loaded into it. In Electron, each window displays web contents that can be loaded\n-from either from a local HTML file...
2022-01-03T08:59:55
golang/go
d1180dbd5e5728d268e0dda01fd2daa261911ec8
01e1e5c20438145df65a2fb79c77e3d5c3eb6831
runtime: relax TestWindowsStackMemory from 100kB to 128kB We've been getting intermittent flakes in this test since 2023, all reporting values just barely over 100kB on windows-386. If we were happy with 100kB, we should be happy with 128kB, and it should fix the flakes. Fixes #58570. Change-Id: Iabe734cfbba6fe28a8...
[ { "path": "src/runtime/syscall_windows_test.go", "patch": "@@ -673,7 +673,7 @@ func TestWindowsStackMemory(t *testing.T) {\n \tif err != nil {\n \t\tt.Fatalf(\"Failed to read stack usage: %v\", err)\n \t}\n-\tif expected, got := 100<<10, stackUsage; got > expected {\n+\tif expected, got := 128<<10, stackUsa...
2024-11-17T15:20:18
ggml-org/llama.cpp
0a10c34dc146b19cc256a66b36321d753899a684
deee23863bb75a67471c62b605248d3ff725c9f0
grammar: Fix grammar root symbol check (#19761) * grammar: fix bad check for root symbol, correct error logging * add tests to demonstrate root symbol check failure
[ { "path": "src/llama-grammar.cpp", "patch": "@@ -1160,13 +1160,13 @@ struct llama_grammar * llama_grammar_init_impl(\n // if there is a grammar, parse it\n // rules will be empty (default) if there are parse errors\n if (!parser.parse(grammar_str) || parser.rules.empty()) {\n- fprintf(std...
2026-03-12T11:04:56
huggingface/transformers
eaab9f2fdedf450de24d46e2e2bb63f12e373349
e23f92b30853a4e776b1512b7d61a9513fcdc3c9
refactor + robusts tests for Tensor Parallel (#42809) * begin Moe test tensor parallel * create tiny moe model + fix test tensor parallel Moe eaeaae * create tiny moe model + fix test tensor parallel Moe eaeaae fix tensor parallel MoE test fix tensor parallel MoE test * fix backward pass test in tensor parallel...
[ { "path": "src/transformers/core_model_loading.py", "patch": "@@ -32,13 +32,10 @@\n \n from .integrations.accelerate import get_device, offload_weight\n from .integrations.tensor_parallel import ALL_PARALLEL_STYLES\n-from .utils import is_env_variable_true, is_torch_greater_or_equal, logging\n+from .utils i...
2026-01-30T15:22:12
vuejs/vue
165a14a6c6c406176037465d2961259c5c980399
bba6b3d6b4e3e26d28abbf20e74ec2f3e64f1a92
fix(ssr): fix on-component directives rendering (#12661) fix #10733
[ { "path": "packages/server-renderer/src/render.ts", "patch": "@@ -206,6 +206,11 @@ function renderComponentInner(node, isRoot, context) {\n type: 'Component',\n prevActive\n })\n+ if (isDef(node.data) && isDef(node.data.directives)) {\n+ childNode.data = childNode.data || {}\n+ ...
2022-08-18T08:22:55
ollama/ollama
42cf4db6017a949c2decd1bb9b6cac2468aceeaf
93a8daf285af45ed71544e79aae0cb15245e75f4
parser: fix parsing Modelfiles with multiple FROM commands (#8449)
[ { "path": "parser/parser.go", "patch": "@@ -62,7 +62,13 @@ func (f Modelfile) CreateRequest(relativeDir string) (*api.CreateRequest, error)\n \t\t\t\treturn nil, err\n \t\t\t}\n \n-\t\t\treq.Files = digestMap\n+\t\t\tif req.Files == nil {\n+\t\t\t\treq.Files = digestMap\n+\t\t\t} else {\n+\t\t\t\tfor k, v :...
2025-01-16T08:14:04
electron/electron
ffbaa1d83f6612ae7f7aac03feeca62973cd36ba
909dbe68908228a2fef6f475d10c3dba4cc39b03
fix: check for single bluetooth listener (#32240)
[ { "path": "lib/browser/api/web-contents.ts", "patch": "@@ -750,7 +750,7 @@ WebContents.prototype._init = function () {\n });\n \n this.on('select-bluetooth-device', (event, devices, callback) => {\n- if (this.listenerCount('select-bluetooth-device') === 0) {\n+ if (this.listenerCount('select-bluet...
2021-12-18T00:55:43
ggml-org/llama.cpp
deee23863bb75a67471c62b605248d3ff725c9f0
c3e3f9e5338e8eb3d5b13d20f20d38b53d9d19ce
vulkan: add GATED_DELTA_NET op support (#20334) * vulkan: add GATED_DELTA_NET op support Implements the fused gated delta net recurrence as a Vulkan compute shader with full support for scalar gate, KDA vector gate, GQA broadcast, multi-token sequences, and permuted (non-contiguous) q/k inputs. Specialization constan...
[ { "path": "ggml/src/ggml-vulkan/ggml-vulkan.cpp", "patch": "@@ -825,6 +825,8 @@ struct vk_device_struct {\n vk_pipeline pipeline_pool2d_f32;\n vk_pipeline pipeline_rwkv_wkv6_f32;\n vk_pipeline pipeline_rwkv_wkv7_f32;\n+ // [size_idx][kda] where size_idx: 0=d32, 1=d64, 2=d128\n+ vk_pipeline...
2026-03-12T10:32:04
golang/go
44d4b6994246094fa2385fafc182b679ef216f3a
f9a95b1bdcff42730c836a792b27740b9c0df645
cmd/go: change Printer.Output -> Printer.Printf for consistency Currently, the Printer interface has `Output`, which acts like Print and `Errorf`, which acts like Printf. It's confusing that the formatting style is tied to whether it's regular output or an error. Fix this by replacing Output with Printf, so both use ...
[ { "path": "src/cmd/go/internal/load/printer.go", "patch": "@@ -17,15 +17,15 @@ import (\n \n // A Printer reports output about a Package.\n type Printer interface {\n-\t// Output reports output from building pkg. The arguments are of the form\n-\t// expected by fmt.Print.\n+\t// Printf reports output from b...
2024-11-14T00:50:44
huggingface/transformers
26c671381c640881c95c0bf2b1a1afbd28cabb94
30088d05a7db331b9741facdab26cec7e6b31e41
minimax_m2: fix failed test case for XPU (#43324) fix failed test case for XPU Signed-off-by: Liu, Kaixuan <kaixuan.liu@intel.com>
[ { "path": "tests/models/minimax_m2/test_modeling_minimax_m2.py", "patch": "@@ -114,21 +114,22 @@ def test_small_model_logits_batched(self):\n EXPECTED_LOGITS_LEFT_UNPADDED = Expectations(\n {\n (\"cuda\", 8): [[1.1094, -1.5352, -1.5811], [1.9395, 0.1461, -1.5537], [1.7803...
2026-01-30T15:03:26
vuejs/vue
bba6b3d6b4e3e26d28abbf20e74ec2f3e64f1a92
9eb8ea5b63eec2b09f268738e9d0e311d9eafb19
feat(types): enhance type for onErrorCaptured (#12735)
[ { "path": "src/v3/apiLifecycle.ts", "patch": "@@ -42,7 +42,6 @@ export const onBeforeUpdate = createLifeCycle('beforeUpdate')\n export const onUpdated = createLifeCycle('updated')\n export const onBeforeUnmount = createLifeCycle('beforeDestroy')\n export const onUnmounted = createLifeCycle('destroyed')\n-ex...
2022-08-18T08:20:27
ollama/ollama
a041b4df7cd8045b1410cdd6988c660427de12ad
2539f2dbf99ec1b8f44ece884bf2c8678fca3127
docs: fix path to examples (#8438)
[ { "path": "docs/README.md", "patch": "@@ -2,7 +2,7 @@\n \n ### Getting Started\n * [Quickstart](../README.md#quickstart)\n-* [Examples](../examples)\n+* [Examples](./examples.md)\n * [Importing models](./import.md)\n * [Linux Documentation](./linux.md)\n * [Windows Documentation](./windows.md)", "additi...
2025-01-15T19:49:12
ggml-org/llama.cpp
c3e3f9e5338e8eb3d5b13d20f20d38b53d9d19ce
40c550d4f6838180fa40eda8351043353911ca40
convert : better mtp check and fix return [no ci] (#20419)
[ { "path": "convert_hf_to_gguf.py", "patch": "@@ -10092,9 +10092,9 @@ def modify_tensors(self, data_torch: Tensor, name: str, bid: int | None) -> Iter\n # Skip Multi-Token Prediction (MTP) tensors. These are used for\n # for speculative decoding but we don't include them in this model...
2026-03-12T09:04:20
electron/electron
e9420982d237bd17261075e8830d9f0cdff724cd
c1b3b3064b7b0a7aafd4ec75d7c59fd44f2b6b21
fix: older systems crash when playing media files (#32046) * fix: win7 crash when playing media * reset * chore: update patches Co-authored-by: PatchUp <73610968+patchup[bot]@users.noreply.github.com>
[ { "path": "patches/chromium/fix_media_key_usage_with_globalshortcuts.patch", "patch": "@@ -59,7 +59,7 @@ index ad366d0fd4c3a637d75a102ab56984f0d01bfc04..d63eb133fd4bab1ea309bb8c742acf88\n // true if register successfully, or false if 1) the specificied |accelerator|\n // has been registered by another...
2021-12-16T17:23:30
huggingface/transformers
797c822a1731af4cb61f3bf71681d0941cd74eef
fc2653be1c1a2830c56945a2ac4ad54300944db1
Fix extras on all supported Python versions (#43490) Makes sure extras can be installed on all supported Python versions. - cleaned up extras (removed natten, tweaked mistral-common etc,) - adds a supported Python version range (10->14) - dynamically update the metadata - run a smoke test in the CI every night to ver...
[ { "path": ".github/workflows/extras-smoke-test.yml", "patch": "@@ -0,0 +1,198 @@\n+name: Extras Smoke Test\n+\n+on:\n+ schedule:\n+ # Run every night at 3 AM UTC\n+ - cron: \"0 3 * * *\"\n+env:\n+ SLACK_CHANNEL_ID: '#transformers-gh-ci-central'\n+\n+jobs:\n+ get-python-versions:\n+ name: Get sup...
2026-01-30T14:27:16
golang/go
f9a95b1bdcff42730c836a792b27740b9c0df645
9060fa5afd52fcdb60c09e26c73f5980520ca9f9
cmd/go: print build errors during go test -json in JSON Currently, if a test or imported package fails to build during "go test -json", the build error text will be interleaved with the JSON output of tests. Furthermore, there’s currently no way to reliably associate a build error with the test package or packages it ...
[ { "path": "doc/next/3-tools.md", "patch": "@@ -2,6 +2,12 @@\n \n ### Go command {#go-command}\n \n+The `go build` and `go install` commands now accept a `-json` flag that reports\n+build output and failures as structured JSON output on standard output.\n+Furthermore, passing `-json` to `go test` now reports...
2023-10-17T21:27:00
vuejs/vue
9eb8ea5b63eec2b09f268738e9d0e311d9eafb19
2263948c249e7486403bc5880712e6d9fd15c17f
chore: fix some legacy doc urls in warnings and readme (#12725) [ci skip]
[ { "path": "README.md", "patch": "@@ -73,7 +73,7 @@ Vue.js supports all browsers that are [ES5-compliant](https://kangax.github.io/c\n \n ## Documentation\n \n-To check out [live examples](https://vuejs.org/v2/examples/) and docs, visit [vuejs.org](https://vuejs.org).\n+To check out [live examples](https://v...
2022-08-18T08:12:20
ollama/ollama
2539f2dbf99ec1b8f44ece884bf2c8678fca3127
61676fb5066fe42f4586d8f951548fcb55cd75bf
Fix absolute path names + gguf detection (#8428)
[ { "path": "parser/expandpath_test.go", "patch": "@@ -4,21 +4,37 @@ import (\n \t\"os\"\n \t\"os/user\"\n \t\"path/filepath\"\n+\t\"runtime\"\n \t\"testing\"\n )\n \n func TestExpandPath(t *testing.T) {\n \tmockCurrentUser := func() (*user.User, error) {\n \t\treturn &user.User{\n \t\t\tUsername: \"testuser\...
2025-01-15T03:01:24
ggml-org/llama.cpp
40c550d4f6838180fa40eda8351043353911ca40
de190154c85d20e24dbeae8c8af1849402ae5098
vulkan: fix SSM_CONV PP scaling with large ubatch sizes (#20379) * vulkan: optimize SSM_CONV workgroup dispatch for large ubatch Tile tokens into 2D workgroups (32x16) to reduce workgroup launch overhead at large ubatch sizes. Add vec4 fast path for nc=4 (common d_conv size). Fixes PP performance degradation with uba...
[ { "path": "ggml/src/ggml-vulkan/ggml-vulkan.cpp", "patch": "@@ -4576,7 +4576,7 @@ static void ggml_vk_load_shaders(vk_device& device) {\n ggml_vk_create_pipeline(device, device->pipeline_ssm_scan_f32_d256, \"ssm_scan_256_f32\", ssm_scan_f32_len, ssm_scan_f32_data, \"main\", 8, sizeof(vk_op_ssm_scan_...
2026-03-12T09:03:18
electron/electron
a11f5cbb271091f5354550aa6c5da1164246c80f
1facbb4a099396fd2db23224226741bdd16717e8
fix: ensure bluetooth devices are not returned by default (#32178)
[ { "path": "docs/api/web-contents.md", "patch": "@@ -736,6 +736,8 @@ first available device will be selected. `callback` should be called with\n `deviceId` to be selected, passing empty string to `callback` will\n cancel the request.\n \n+If no event listener is added for this event, all bluetooth requests w...
2021-12-15T19:46:48
golang/go
49b3ab0d81824f060b9ba459a076f6ff9ad04bc6
7020759859a3b7c2f033e497eca750b15d3aa38d
cmd/go: report all loading errors in tests as "setup failed" Currently, under *most* circumstances, if there's a package loading error during "go test", that will get reported as a "FAIL p [setup failed]" or "FAIL p [build failed] message and won't prevent running unaffected test packages. However, if there's a loadi...
[ { "path": "src/cmd/go/internal/load/test.go", "patch": "@@ -176,8 +176,10 @@ func TestPackagesAndErrors(ctx context.Context, done func(), opts PackageOpts, p\n \tif len(p.TestGoFiles) > 0 || p.Name == \"main\" || cover != nil && cover.Local {\n \t\tptest = new(Package)\n \t\t*ptest = *p\n-\t\tptest.Error = ...
2024-01-26T19:45:30
vuejs/vue
2263948c249e7486403bc5880712e6d9fd15c17f
5221d4d3b6049c87d196d99dbb64bcd3f3b07279
fix: directives shorthand normalize error (#12744) fix #12743
[ { "path": "src/core/vdom/modules/directives.ts", "patch": "@@ -103,7 +103,15 @@ function normalizeDirectives(\n }\n res[getRawDirName(dir)] = dir\n if (vm._setupState && vm._setupState.__sfc) {\n- dir.def = dir.def || resolveAsset(vm, '_setupState', 'v-' + dir.name)\n+ const setupDef =...
2022-08-18T08:11:47
ggml-org/llama.cpp
05039967da783fa8c7b8bc51e80ae834ab1cda73
e4cff0956b0dd7196cd8d4717daf02329cdeb870
ggml-virtgpu: Fix some build commands (#20341)
[ { "path": "docs/backend/VirtGPU/development.md", "patch": "@@ -55,7 +55,8 @@ LLAMA_MAC_BUILD=$PWD/build/ggml-virtgpu-backend\n cmake -S . -B $LLAMA_MAC_BUILD \\\n -DGGML_NATIVE=OFF \\\n -DLLAMA_CURL=ON \\\n- -DGGML_REMOTINGBACKEND=ONLY \\\n+ -DGGML_VIRTGPU=ON \\\n+ -DGGML_VIRTGPU_...
2026-03-12T07:47:45
electron/electron
6d9e2e3ad080f97d379ad4ca8af389d09eadd397
c4e471fbe2f89f4c665ef706f12e04f6d2bfb9d9
docs: Fix environment variable name (#32094) The names of environment variables are case-sensitive on Linux and Mac.
[ { "path": "docs/tutorial/installation.md", "patch": "@@ -91,7 +91,7 @@ The above configuration will download from URLs such as\n `https://npmmirror.com/mirrors/electron/8.0.0/electron-v8.0.0-linux-x64.zip`.\n \n If your mirror serves artifacts with different checksums to the official\n-Electron release you ...
2021-12-13T06:42:43
golang/go
7020759859a3b7c2f033e497eca750b15d3aa38d
47da5a303f642c7c863e0fe9a5554fb85dd45d68
cmd/go: implement "go build -json" This adds support for a "-json" flag in all build-related go subcommands. This causes build output and build failures to be reported to stdout in a machine-readable way. For #62067. Fixes #23037. Change-Id: Id045c5bd5dde9d16cc09dde6248a4b9637896a30 Reviewed-on: https://go-review.go...
[ { "path": "src/cmd/go/alldocs.go", "patch": "@@ -38,6 +38,7 @@\n // Additional help topics:\n //\n //\tbuildconstraint build constraints\n+//\tbuildjson build -json encoding\n //\tbuildmode build modes\n //\tc calling between Go and C\n //\tcache build and test caching\n@...
2023-08-24T17:29:39
ggml-org/llama.cpp
e4cff0956b0dd7196cd8d4717daf02329cdeb870
4cc6eb158c83a3b9833526f3bf1175696884fb0c
metal : avoid divisions in bin kernel (#20426) * metal : avoid modulus in bin kernel when not broadcasting * metal : fix capture_started flag
[ { "path": "ggml/src/ggml-metal/ggml-metal-context.m", "patch": "@@ -554,7 +554,7 @@ enum ggml_status ggml_metal_graph_compute(ggml_metal_t ctx, struct ggml_cgraph *\n \n // enter here only when capturing in order to wait for all computation to finish\n // otherwise, we leave the graph to com...
2026-03-12T07:42:40
vuejs/vue
5221d4d3b6049c87d196d99dbb64bcd3f3b07279
89a6b5e8658a6e3ae2cf649829901784ac9deb3c
fix(compiler-sfc): rewriteDefault for class with decorators (#12747)
[ { "path": "packages/compiler-sfc/src/rewriteDefault.ts", "patch": "@@ -42,7 +42,12 @@ export function rewriteDefault(\n }).program.body\n ast.forEach(node => {\n if (node.type === 'ExportDefaultDeclaration') {\n- s.overwrite(node.start!, node.declaration.start!, `const ${as} = `)\n+ if (no...
2022-08-18T08:01:00
golang/go
47da5a303f642c7c863e0fe9a5554fb85dd45d68
5ebb4e282e72ac14d20a845601921739a072e953
cmd/go: add Printer interface and use for error reporting This replaces the existing Shell print function callback. The interface also gives us a way to report build failures, which is the other type of event that will appear in the build -json output. This CL hooks up error reporting in two places: - In Builder.Do,...
[ { "path": "src/cmd/go/internal/clean/clean.go", "patch": "@@ -150,7 +150,7 @@ func runClean(ctx context.Context, cmd *base.Command, args []string) {\n \t\t}\n \t}\n \n-\tsh := work.NewShell(\"\", fmt.Print)\n+\tsh := work.NewShell(\"\", &load.TextPrinter{Writer: os.Stdout})\n \n \tif cleanCache {\n \t\tdir,...
2023-10-17T20:30:36
electron/electron
35ac7fb8e61be744206918684a6881d460591620
77287febf43e86c086ab49029b7e4b94b844a0d9
fix: window.open not overriding parent's webPreferences (#32057) * fix: window.open not overriding parent's webPreferences * test: remove "nativeWindowOpen: false" from renderer tests
[ { "path": "docs/api/window-open.md", "patch": "@@ -64,6 +64,9 @@ window.open('https://github.com', '_blank', 'top=500,left=200,frame=false,nodeIn\n `features` will be passed to any registered `webContents`'s\n `did-create-window` event handler in the `options` argument.\n * `frameName` follows the speci...
2021-12-06T03:54:14
ggml-org/llama.cpp
246ffc4b057504712272433b035afefc78457cda
aa429cf5075ef1cf14c9cf784c73fc436ff6eede
vulkan: fix l2_norm epsilon handling (#20350)
[ { "path": "ggml/src/ggml-vulkan/ggml-vulkan.cpp", "patch": "@@ -16061,7 +16061,7 @@ static void ggml_vk_check_results_0(ggml_backend_vk_context * ctx, ggml_cgraph *\n tensor_clone = ggml_arange(ggml_ctx, start, stop, step);\n } else if (tensor->op == GGML_OP_FILL) {\n const f...
2026-03-12T05:39:41
vuejs/vue
b4bf4c52ad31e02307cfd4d643dc5610c893e3ba
80d1baf92050da411fb1bfe714401c498001dd36
fix(types): allow attaching unknown options to defined component fix #12742
[ { "path": "types/test/v3/define-component-test.tsx", "patch": "@@ -1165,3 +1165,7 @@ defineComponent({\n return h('div', {}, [...this.$slots.default!])\n }\n })\n+\n+// #12742 allow attaching custom properties (consistent with v3)\n+const Foo = defineComponent({})\n+Foo.foobar = 123", "additions":...
2022-08-18T07:32:12
huggingface/transformers
10873014241aaddb23b68de98f6d398626febca0
f7069c4e0b73b19f140c4a339b4d47aaddbb43d1
fix(models): Fix suno/bark-small CPU offload device mismatch causing CI failures (#43607) fix(bark): Ensure device consistency during CPU offload
[ { "path": "src/transformers/models/bark/modeling_bark.py", "patch": "@@ -474,8 +474,6 @@ def forward(\n batch_size = input_embeds.shape[0]\n seq_length = input_shape[-1]\n \n- device = input_ids.device if input_ids is not None else input_embeds.device\n-\n if self.gradient_che...
2026-01-30T13:11:05